@@ -1,30 +1,30 @@
 use v6;
 
 use PDF::Class::Type; # just to help rakudo
-use PDF::DAO::Tie;
-use PDF::DAO::Tie::Hash;
+use PDF::COS::Tie;
+use PDF::COS::Tie::Hash;
 
 #| Appearance role - see PDF::Annot - /AP entry
 
 role PDF::Appearance
-    does PDF::DAO::Tie::Hash {
+    does PDF::COS::Tie::Hash {
 
 # See [PDF 1.7 TABLE 8.19 Entries in an appearance dictionary]
 
-    use PDF::DAO;
-    use PDF::DAO::Tie;
-    use PDF::DAO::Stream;
+    use PDF::COS;
+    use PDF::COS::Tie;
+    use PDF::COS::Stream;
 
     my role AppearanceStatus
-	does PDF::DAO::Tie::Hash {
-	has PDF::DAO::Stream $.Off is entry;
-	has PDF::DAO::Stream $.On is entry;
-	has PDF::DAO::Stream $.Yes is entry;
+	does PDF::COS::Tie::Hash {
+	has PDF::COS::Stream $.Off is entry;
+	has PDF::COS::Stream $.On is entry;
+	has PDF::COS::Stream $.Yes is entry;
     }
     #| /Type entry is optional, but should be /Pattern when present
-    my subset AppearanceEntry of PDF::DAO where PDF::DAO::Stream | AppearanceStatus;
+    my subset AppearanceEntry of PDF::COS where PDF::COS::Stream | AppearanceStatus;
     multi sub coerce(Hash $dict is rw, AppearanceEntry) {
-	PDF::DAO.coerce($dict,  AppearanceStatus)
+	PDF::COS.coerce($dict,  AppearanceStatus)
     }
 
     has AppearanceEntry $.N is entry(:&coerce, :alias<normal>, :required); #| (Required) The annotation’s normal appearance.
