@@ -10,6 +10,7 @@ class PDF::Font::Type0
 	has PDF::COS::Name $.BaseFont is entry(:required); #| (Required) The PostScript name of the font. In principle, this is an arbitrary name, since there is no font program associated directly with a Type 0 font dictionary.
 	subset NameOrStream of PDF::COS where PDF::COS::Name | PDF::COS::Stream;
         has NameOrStream $.Encoding is entry(:required);   #| (Required) The name of a predefined CMap, or a stream containing a CMap that maps character codes to font numbers and CIDs.
-	has PDF::Font @.DescendantFonts is entry(:required,:len(1));    #| (Required) A one-element array specifying the CIDFont dictionary that is the descendant of this Type 0 font.
+        use PDF::Font::CIDFont;
+	has PDF::Font::CIDFont @.DescendantFonts is entry(:required,:len(1));    #| (Required) A one-element array specifying the CIDFont dictionary that is the descendant of this Type 0 font.
         has PDF::COS::Stream $.ToUnicode is entry;         #| (Optional) A stream containing a CMap file that maps character codes to Unicode values
 }
